==> eam-wshub-proxyclient-11.4-10-sources.jar: net/datastream/schemas/mp_fields/TARGETPROMPTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour TARGETPROMPTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="TARGETPROMPTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TARGETPROMPT"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROMPTDESC" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TARGETPROMPTID_Type", propOrder = {
    "targetprompt",
    "promptdesc"
})
public class TARGETPROMPTID_Type {

    @XmlElement(name = "TARGETPROMPT")
    protected long targetprompt;
    @XmlElement(name = "PROMPTDESC")
    protected String promptdesc;

    /**
     * Obtient la valeur de la propriété targetprompt.
     * 
     */
    public long getTARGETPROMPT() {
        return targetprompt;
    }

    /**
     * Définit la valeur de la propriété targetprompt.
     * 
     */
    public void setTARGETPROMPT(long value) {
        this.targetprompt = value;
    }

    /**
     * Obtient la valeur de la propriété promptdesc.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROMPTDESC() {
        return promptdesc;
    }

    /**
     * Définit la valeur de la propriété promptdesc.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROMPTDESC(String value) {
        this.promptdesc = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/TARGETPROMPTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TARGETPROMPTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TARGETPROMPTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TARGETPROMPT"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROMPTDESC" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TARGETPROMPTID_Type", propOrder = {
    "targetprompt",
    "promptdesc"
})
public class TARGETPROMPTID_Type {

    @XmlElement(name = "TARGETPROMPT")
    protected long targetprompt;
    @XmlElement(name = "PROMPTDESC")
    protected String promptdesc;

    /**
     * Gets the value of the targetprompt property.
     * 
     */
    public long getTARGETPROMPT() {
        return targetprompt;
    }

    /**
     * Sets the value of the targetprompt property.
     * 
     */
    public void setTARGETPROMPT(long value) {
        this.targetprompt = value;
    }

    /**
     * Gets the value of the promptdesc property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROMPTDESC() {
        return promptdesc;
    }

    /**
     * Sets the value of the promptdesc property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROMPTDESC(String value) {
        this.promptdesc = value;
    }

}
